#ifndef NT2_INCLUDE_CONSTANTS_SQRTVALMAX_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SQRTVALMAX_HPP_INCLUDED

#include <nt2/constant/include/constants/sqrtvalmax.hpp>

#endif
